Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(245)

Unified Diff: components/mus/ws/server_view_surface.h

Issue 1406153004: components/mus/public/interfaces View => Window (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Yet another rebase Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/ws/server_view_observer.h ('k') | components/mus/ws/server_view_surface.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/server_view_surface.h
diff --git a/components/mus/ws/server_view_surface.h b/components/mus/ws/server_view_surface.h
index f743e6fa9d338ed6aae3bd5bf0ed104f990e4462..5bfec39595868f563a3db4229d92458ad7d9bcc4 100644
--- a/components/mus/ws/server_view_surface.h
+++ b/components/mus/ws/server_view_surface.h
@@ -20,7 +20,7 @@ class ServerView;
class SurfacesState;
// Server side representation of a ViewSurface.
-class ServerViewSurface : public mojo::Surface,
+class ServerViewSurface : public mojom::Surface,
public cc::SurfaceFactoryClient,
public mojo::CustomSurfaceConverter {
public:
@@ -29,11 +29,11 @@ class ServerViewSurface : public mojo::Surface,
~ServerViewSurface() override;
void Bind(mojo::InterfaceRequest<Surface> request,
- mojo::SurfaceClientPtr client);
+ mojom::SurfaceClientPtr client);
- // mojo::Surface:
+ // mojom::Surface:
void SubmitCompositorFrame(
- mojo::CompositorFramePtr frame,
+ mojom::CompositorFramePtr frame,
const SubmitCompositorFrameCallback& callback) override;
// Returns the set of views referenced by the last CompositorFrame submitted
@@ -45,16 +45,16 @@ class ServerViewSurface : public mojo::Surface,
const cc::SurfaceId& id() const { return surface_id_; }
private:
// Takes a mojo::CompositorFrame |input|, and converts it into a
// cc::CompositorFrame. Along the way, this conversion ensures that a
// CompositorFrame of this view can only refer to views within its subtree.
// Views referenced in |input| are stored in |referenced_view_ids_|.
scoped_ptr<cc::CompositorFrame> ConvertCompositorFrame(
- const mojo::CompositorFramePtr& input);
+ const mojom::CompositorFramePtr& input);
// Overriden from CustomSurfaceConverter:
- bool ConvertSurfaceDrawQuad(const mojo::QuadPtr& input,
- const mojo::CompositorFrameMetadataPtr& metadata,
+ bool ConvertSurfaceDrawQuad(const mojom::QuadPtr& input,
+ const mojom::CompositorFrameMetadataPtr& metadata,
cc::SharedQuadState* sqs,
cc::RenderPass* render_pass) override;
@@ -75,7 +75,7 @@ class ServerViewSurface : public mojo::Surface,
cc::SurfaceIdAllocator surface_id_allocator_;
cc::SurfaceFactory surface_factory_;
- mojo::SurfaceClientPtr client_;
+ mojom::SurfaceClientPtr client_;
mojo::Binding<Surface> binding_;
DISALLOW_COPY_AND_ASSIGN(ServerViewSurface);
« no previous file with comments | « components/mus/ws/server_view_observer.h ('k') | components/mus/ws/server_view_surface.cc » ('j') | no next file with comments »
@@ -45,16 +45,16 @@ class ServerViewSurface : public mojo::Surface,
const cc::SurfaceId& id() const { return surface_id_; }
private:
- // Takes a mojo::CompositorFrame |input|, and converts it into a
+ // Takes a mojom::CompositorFrame |input|, and converts it into a
// cc::CompositorFrame. Along the way, this conversion ensures that a
// CompositorFrame of this view can only refer to views within its subtree.

Powered by Google App Engine
This is Rietveld 408576698